@@ -596,7 +596,7 @@ mod tests {
         for (source_ids, expected_result) in test_tuples.iter() {
             assert_eq!(
                 bert_tokenizer.decode(
-                    source_ids.clone(),
+                    source_ids,
                     skip_special_tokens,
                     clean_up_tokenization_spaces,
                 ),
@@ -606,7 +606,7 @@ mod tests {
         assert_eq!(
             Tokenizer::decode_list(
                 &bert_tokenizer,
-                source_ids.clone(),
+                &source_ids,
                 skip_special_tokens,
                 clean_up_tokenization_spaces,
             ),
@@ -615,7 +615,7 @@ mod tests {
         assert_eq!(
             MultiThreadedTokenizer::decode_list(
                 &bert_tokenizer,
-                source_ids,
+                &source_ids,
                 skip_special_tokens,
                 clean_up_tokenization_spaces,
             ),
@@ -641,7 +641,7 @@ mod tests {
         for (source_ids, expected_result) in test_tuples.iter() {
             assert_eq!(
                 bert_tokenizer.decode(
-                    source_ids.clone(),
+                    source_ids,
                     skip_special_tokens,
                     clean_up_tokenization_spaces,
                 ),
@@ -651,7 +651,7 @@ mod tests {
         assert_eq!(
             Tokenizer::decode_list(
                 &bert_tokenizer,
-                source_ids.clone(),
+                &source_ids,
                 skip_special_tokens,
                 clean_up_tokenization_spaces,
             ),
@@ -660,7 +660,7 @@ mod tests {
         assert_eq!(
             MultiThreadedTokenizer::decode_list(
                 &bert_tokenizer,
-                source_ids,
+                &source_ids,
                 skip_special_tokens,
                 clean_up_tokenization_spaces,
             ),
