@@ -419,7 +419,7 @@ mod tests {
         for (source_ids, expected_result) in test_tuples.iter() {
             assert_eq!(
                 ctrl_tokenizer.decode(
-                    source_ids.clone(),
+                    source_ids,
                     skip_special_tokens,
                     clean_up_tokenization_spaces
                 ),
@@ -429,7 +429,7 @@ mod tests {
         assert_eq!(
             Tokenizer::decode_list(
                 &ctrl_tokenizer,
-                source_ids,
+                &source_ids,
                 skip_special_tokens,
                 clean_up_tokenization_spaces
             ),
@@ -454,7 +454,7 @@ mod tests {
         for (source_ids, expected_result) in test_tuples.iter() {
             assert_eq!(
                 ctrl_tokenizer.decode(
-                    source_ids.clone(),
+                    source_ids,
                     skip_special_tokens,
                     clean_up_tokenization_spaces
                 ),
@@ -464,7 +464,7 @@ mod tests {
         assert_eq!(
             Tokenizer::decode_list(
                 &ctrl_tokenizer,
-                source_ids,
+                &source_ids,
                 skip_special_tokens,
                 clean_up_tokenization_spaces
             ),
