@@ -38,6 +38,7 @@ pub(crate) mod base_tokenizer;
 mod bert_tokenizer;
 mod constants;
 mod ctrl_tokenizer;
+mod fnet_tokenizer;
 mod gpt2_tokenizer;
 mod m2m100_tokenizer;
 mod marian_tokenizer;
@@ -58,6 +59,7 @@ pub use albert_tokenizer::AlbertTokenizer;
 pub use base_tokenizer::{BaseTokenizer, MultiThreadedTokenizer, Tokenizer, TruncationStrategy};
 pub use bert_tokenizer::BertTokenizer;
 pub use ctrl_tokenizer::CtrlTokenizer;
+pub use fnet_tokenizer::FNetTokenizer;
 pub use gpt2_tokenizer::Gpt2Tokenizer;
 pub use m2m100_tokenizer::M2M100Tokenizer;
 pub use marian_tokenizer::MarianTokenizer;
