@@ -602,7 +602,7 @@ mod tests {
         for (source_ids, expected_result) in test_tuples.iter() {
             assert_eq!(
                 roberta_tokenizer.decode(
-                    source_ids.clone(),
+                    source_ids,
                     skip_special_tokens,
                     clean_up_tokenization_spaces,
                 ),
@@ -612,7 +612,7 @@ mod tests {
         assert_eq!(
             Tokenizer::decode_list(
                 &roberta_tokenizer,
-                source_ids,
+                &source_ids,
                 skip_special_tokens,
                 clean_up_tokenization_spaces,
             ),
