@@ -36,6 +36,7 @@ mod albert_vocab;
 pub(crate) mod base_vocab;
 mod bert_vocab;
 pub(crate) mod bpe_vocab;
+mod fnet_vocab;
 mod gpt2_vocab;
 mod m2m100_vocab;
 mod marian_vocab;
@@ -57,6 +58,7 @@ pub use albert_vocab::AlbertVocab;
 pub use base_vocab::{BaseVocab, Vocab};
 pub use bert_vocab::BertVocab;
 pub use bpe_vocab::{BpePairRef, BpePairVocab};
+pub use fnet_vocab::FNetVocab;
 pub use gpt2_vocab::Gpt2Vocab;
 pub use m2m100_vocab::M2M100Vocab;
 pub use marian_vocab::MarianVocab;
